==> org.apache.sling.query-4.0.2-source-release.zip: org.apache.sling.query-4.0.2/src/test/java/org/apache/sling/query/HasTest.java <==
/*-
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.sling.query;

import static org.apache.sling.query.SlingQuery.$;
import static org.apache.sling.query.TestUtils.assertResourceSetEquals;

import org.apache.sling.api.resource.Resource;
import org.apache.sling.query.api.SearchStrategy;
import org.junit.Test;

public class HasTest {

	private static final String PAR_PATH = "home/java";

	private Resource tree = TestUtils.getTree();

	@Test
	public void testHas() {
		SlingQuery query = $(tree.getChild(PAR_PATH)).searchStrategy(SearchStrategy.DFS).children()
				.has("demo/core/components/configValue");
		assertResourceSetEquals(query.iterator(), "labels");
	}

	@Test
	public void testHasResource() {
		SlingQuery query = $(tree.getChild(PAR_PATH)).children().has(
				$(tree.getChild("home/java/labels/jcr:content/par")));
		assertResourceSetEquals(query.iterator(), "labels");
	}

}

==> org.apache.sling.query-4.0.4-source-release.zip: org.apache.sling.query-4.0.4/src/test/java/org/apache/sling/query/HasTest.java <==
/*-
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.sling.query;

import static org.apache.sling.query.SlingQuery.$;
import static org.apache.sling.query.TestUtils.assertResourceSetEquals;

import org.apache.sling.api.resource.Resource;
import org.apache.sling.query.api.SearchStrategy;
import org.junit.Test;

public class HasTest {

    private static final String PAR_PATH = "home/java";

    private Resource tree = TestUtils.getTree();

    @Test
    public void testHas() {
        SlingQuery query = $(tree.getChild(PAR_PATH)).searchStrategy(SearchStrategy.DFS).children()
                .has("demo/core/components/configValue");
        assertResourceSetEquals(query.iterator(), "labels");
    }

    @Test
    public void testHasResource() {
        SlingQuery query = $(tree.getChild(PAR_PATH)).children()
                .has($(tree.getChild("home/java/labels/jcr:content/par")));
        assertResourceSetEquals(query.iterator(), "labels");
    }

}
